import React from 'react';
import { PropsWithMetadata, noop } from '@highlight-ui/utils-commons';
export declare type DrawerProps = PropsWithMetadata<{
    /** Should be an instance of `DrawerHeader` followed by an instance of `DrawerBody` */
    children?: React.ReactNode;
    /** Allows providing a custom class name */
    className?: string;
    /**
     * Event keycode that should trigger the drawer to close.
     * Please, refer to [KeyboardEvent.key docs on MDN](https://developer.mozilla.org/en-US/docs/Web/API/KeyboardEvent/key) for more details.
     */
    closeKey?: React.KeyboardEvent['key'];
    /** Controls the scrolling behavior of the document when the drawer is open */
    disabledBodyScrolling?: boolean;
    /** Controls the width of the drawer: `(100% - leftOffset)` */
    leftOffset?: React.CSSProperties['left'];
    /** Callback that is invoked after the drawer is closed */
    onClose?: typeof noop;
    /** Callback that is invoked after the drawer is opened */
    onOpen?: typeof noop;
    /** Callback that is invoked when the close key is pressed (if `preventToClose` is set to `false`) */
    onRequestToClose?: typeof noop;
    /** Controls whether the `onRequestToClose` callback should be executed or not */
    preventToClose?: boolean;
    /** Controls the height of the drawer: `(100% - topOffset)` */
    topOffset?: React.CSSProperties['top'];
    /** Controls the visibility of the drawer */
    visible?: boolean;
}>;
declare const Drawer: React.FC<DrawerProps>;
export default Drawer;
