import React, { useRef, useCallback, useEffect } from 'react';
import ReactDOM from 'react-dom';
import classnames from 'classnames';
import { parseMetadata, noop } from '@highlight-ui/utils-commons';
/*! *****************************************************************************
Copyright (c) Microsoft Corporation.

Permission to use, copy, modify, and/or distribute this software for any
purpose with or without fee is hereby granted.

THE SOFTWARE IS PROVIDED "AS IS" AND THE AUTHOR DISCLAIMS ALL WARRANTIES WITH
REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF MERCHANTABILITY
AND FITNESS. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY SPECIAL, DIRECT,
INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES WHATSOEVER RESULTING FROM
LOSS OF USE, DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR
OTHER TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
PERFORMANCE OF THIS SOFTWARE.
***************************************************************************** */

var __assign = function () {
  __assign = Object.assign || function __assign(t) {
    for (var s, i = 1, n = arguments.length; i < n; i++) {
      s = arguments[i];

      for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p)) t[p] = s[p];
    }

    return t;
  };

  return __assign.apply(this, arguments);
};

function __rest(s, e) {
  var t = {};

  for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p) && e.indexOf(p) < 0) t[p] = s[p];

  if (s != null && typeof Object.getOwnPropertySymbols === "function") for (var i = 0, p = Object.getOwnPropertySymbols(s); i < p.length; i++) {
    if (e.indexOf(p[i]) < 0 && Object.prototype.propertyIsEnumerable.call(s, p[i])) t[p[i]] = s[p[i]];
  }
  return t;
}

var styles$1 = {
  "drawerContainer": "Drawer-module__37T18NwR__v5-2-5"
};

var Drawer = function (_a) {
  var _b = _a.visible,
      visible = _b === void 0 ? false : _b,
      _c = _a.disabledBodyScrolling,
      disabledBodyScrolling = _c === void 0 ? true : _c,
      _d = _a.preventToClose,
      preventToClose = _d === void 0 ? false : _d,
      _e = _a.closeKey,
      closeKey = _e === void 0 ? 'Escape' : _e,
      _f = _a.topOffset,
      topOffset = _f === void 0 ? '0px' : _f,
      _g = _a.leftOffset,
      leftOffset = _g === void 0 ? '280px' : _g,
      className = _a.className,
      children = _a.children,
      _h = _a.onOpen,
      onOpen = _h === void 0 ? noop : _h,
      _j = _a.onClose,
      onClose = _j === void 0 ? noop : _j,
      _k = _a.onRequestToClose,
      onRequestToClose = _k === void 0 ? noop : _k,
      metadata = _a.metadata,
      remainingProps = __rest(_a, ["visible", "disabledBodyScrolling", "preventToClose", "closeKey", "topOffset", "leftOffset", "className", "children", "onOpen", "onClose", "onRequestToClose", "metadata"]);

  var prevPropVisible = useRef(visible);
  var ref = useRef(null);
  var determineBodyOverflowStyle = useCallback(function () {
    /**
     * Set overflow hidden in order to prevent body scrolling while
     * the full modal is opened
     */
    if (disabledBodyScrolling) {
      window.document.body.style.overflowY = visible ? 'hidden' : 'unset';
    }
  }, [disabledBodyScrolling, visible]);
  var handleKeyDown = useCallback(function (event) {
    var closeKeyWasPressed = String(event.key) === String(closeKey);

    if (closeKeyWasPressed && !preventToClose) {
      onRequestToClose();
    }
  }, [closeKey, onRequestToClose, preventToClose]);
  useEffect(function () {
    if (visible) {
      document.addEventListener('keydown', handleKeyDown);
    }

    determineBodyOverflowStyle();
    return function () {
      document.removeEventListener('keydown', handleKeyDown);
    }; // eslint-disable-next-line react-hooks/exhaustive-deps
  }, [determineBodyOverflowStyle]);
  useEffect(function () {
    if (visible !== prevPropVisible.current) {
      prevPropVisible.current = visible; // Prop callbacks

      if (visible) {
        onOpen();
      } else {
        onClose();
      }

      determineBodyOverflowStyle(); // Add / Remove event for closing using keyboard

      if (visible) {
        document.addEventListener('keydown', handleKeyDown);
      } else {
        document.removeEventListener('keydown', handleKeyDown);
      }
    }
  }, [determineBodyOverflowStyle, handleKeyDown, onClose, onOpen, visible]);
  var sizeStyle = {
    top: topOffset,
    left: leftOffset,
    width: "calc(100% - " + leftOffset + ")",
    height: "calc(100% - " + topOffset + ")"
  };
  var Component = /*#__PURE__*/React.createElement("div", __assign({}, remainingProps, parseMetadata(metadata), {
    className: classnames(styles$1.drawerContainer, className),
    style: sizeStyle,
    "data-state": visible && 'show',
    ref: ref,
    role: "dialog",
    "aria-hidden": !visible,
    "aria-modal": visible || undefined
  }), children);
  return /*#__PURE__*/ReactDOM.createPortal(Component, window.document.body);
};

var DrawerBody = /*#__PURE__*/React.forwardRef(function (_a, ref) {
  var className = _a.className,
      children = _a.children,
      metadata = _a.metadata;
  return /*#__PURE__*/React.createElement("div", __assign({}, parseMetadata(metadata), {
    className: classnames(className),
    ref: ref
  }), children);
});
var DrawerBody$1 = /*#__PURE__*/React.memo(DrawerBody);
var styles = {
  "drawerHeaderContainer": "DrawerHeader-module__610UTmqX__v5-2-5",
  "drawerHeaderContainerFixed": "DrawerHeader-module__1C_oNt0Y__v5-2-5",
  "drawerHeaderContainerFixedWithScroll": "DrawerHeader-module__1jW-TnjL__v5-2-5"
};

var DrawerHeader = function (_a) {
  var _b;

  var _c = _a.fixed,
      fixed = _c === void 0 ? false : _c,
      className = _a.className,
      children = _a.children,
      metadata = _a.metadata;
  var prevPropFixed = useRef(fixed);
  var ref = useRef(null);
  var onScroll = useCallback(function (event) {
    var _a = event.currentTarget.scrollTop,
        scrollTop = _a === void 0 ? 0 : _a;
    var appendFixedClass = scrollTop !== 0;

    if (ref.current) {
      ref.current.classList[appendFixedClass ? 'add' : 'remove'](styles.drawerHeaderContainerFixedWithScroll);
    }
  }, []);
  useEffect(function () {
    var _a;

    if (ref.current || prevPropFixed.current !== fixed) {
      var parentEl = (_a = ref.current) === null || _a === void 0 ? void 0 : _a.parentElement; // Make sure just to add the event if is the drawer element

      var drawerEl = parentEl && parentEl.getAttribute('role') === 'dialog' ? parentEl : null;

      if (!drawerEl) {
        return;
      }

      if (fixed) {
        drawerEl.addEventListener('scroll', onScroll);
      } else {
        drawerEl.removeEventListener('scroll', onScroll);
      }
    }

    prevPropFixed.current = fixed;
  }, [ref, fixed, onScroll]);
  var containerClassName = classnames((_b = {}, _b[styles.drawerHeaderContainerFixed] = fixed, _b), styles.drawerHeaderContainer, className);
  return /*#__PURE__*/React.createElement("div", __assign({}, parseMetadata(metadata), {
    className: containerClassName,
    ref: ref
  }), children);
};

export { Drawer, DrawerBody$1 as DrawerBody, DrawerHeader };
//# sourceMappingURL=index.js.map
